@@ -1,12 +1,12 @@
 from models import City, Country
 import factory
 
-class CityFactory(factory.Factory):
+class CityFactory(factory.DjangoModelFactory):
     FACTORY_FOR = City
 
     remote_id = factory.Sequence(lambda n: n)
 
-class CountryFactory(factory.Factory):
+class CountryFactory(factory.DjangoModelFactory):
     FACTORY_FOR = Country
 
     remote_id = factory.Sequence(lambda n: n)
\ No newline at end of file
